<TS language="be" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Стварыць новы адрас</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Новы</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Капіяваць пазначаны адрас у сістэмны буфер абмену</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Капіяваць</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Зачыніць</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Выдаліць абраны адрас са спісу</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Увядзіце адрас ці пазнаку для пошуку</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Экспартаваць гэтыя звесткі у файл</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>Экспарт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Выдаліць</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Выбраць адрас, куды выслаць сродкі</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Выбраць адрас, на які атрымаць сродкі</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Выбраць</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>адрасы Адпраўкі</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>адрасы Прымання</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Тут знаходзяцца Біткойн-адрасы для высылання плацяжоў. Заўсёды спраўджвайце колькасць і адрас прызначэння перад здзяйсненнем транзакцыі.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Капіяваць адрас</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Капіяваць Метку</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Рэдагаваць</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Экспартаваць Спіс Адрасоў</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Коскамі падзелены файл (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспартаванне няўдалае</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Адбылася памылка падчас спробы захаваць адрас у %1. Паспрабуйце зноў.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрас</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Дыялог сакрэтнай фразы</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Увядзіце кодавую фразу</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Новая кодавая фраза</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Паўтарыце новую кодавую фразу</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Паказаць кодавую фразу</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Зашыфраваць гаманец.</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Гэтая аперацыя патрабуе кодавую фразу, каб рзблакаваць гаманец.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Разблакаваць гаманец</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Гэтая аперацыя патрабуе пароль каб расшыфраваць гаманец.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Рачшыфраваць гаманец</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Змяніць пароль</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Пацвердзіце шыфраванне гаманца</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Увага: калі вы зашыфруеце свой гаманец і страціце парольную фразу, то &lt;b&gt;СТРАЦІЦЕ ЎСЕ СВАЕ БІТКОЙНЫ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ці ўпэўненыя вы, што жадаеце зашыфраваць свой гаманец?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Гаманец зашыфраваны</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Увядзіце новы пароль для гаманца.&lt;br/&gt;Парольная фраза павинна складацца&lt;b&gt; не меньш чым з дзесяці сімвалаў&lt;/b&gt;, ці &lt;b&gt;больш чым з васьмі слоў&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Увядзіце стары пароль і новы пароль для гаманца.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>ВАЖНА: Усе папярэднія копіі гаманца варта замяніць новым зашыфраваным файлам. У мэтах бяспекі папярэднія копіі незашыфраванага файла-гаманца стануць неўжывальнымі, калі вы станеце карыстацца новым зашыфраваным гаманцом.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Шыфраванне гаманца няўдалае</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Шыфраванне гаманца не адбылося з-за ўнутранай памылкі. Гаманец незашыфраваны.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Уведдзеныя паролі не супадаюць</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Разблакаванне гаманца няўдалае</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Уведзены пароль  для расшыфравання гаманца памылковы</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Расшыфраванне гаманца няўдалае</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Парольная фраза гаманца паспяхова зменена.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Увага: Caps Lock уключаны!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Падпісаць паведамленне...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Сінхранізацыя з сецівам...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>Агляд</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Паказвае агульныя звесткі аб гаманцы</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>Транзакцыі</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Праглядзець гісторыю транзакцый</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Выйсці</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Выйсці з праграмы</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Паказаць інфармацыю аб %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Аб Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Паказаць інфармацыю аб Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Опцыі...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Зашыфраваць Гаманец...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Стварыць копію гаманца...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Адчыниць &amp;URI...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Гаманец:</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Пераіндэксацыя блокаў на дыску...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Даслаць манеты на Біткойн-адрас</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Зрабіце копію гаманца ў іншае месца</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Змяніць пароль шыфравання гаманца</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Праверыць паведамленне...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Даслаць</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Атрымаць</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Паказаць / Схаваць</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Паказаць альбо схаваць галоўнае вакно</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Зашыфраваць прыватныя ключы, якия належаць вашаму гаманцу</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Падпісаць паведамленне з дапамогай Біткойн-адраса каб даказаць, што яно належыць вам</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Спраўдзіць паведамленне з дапамогай Біткойн-адраса каб даказаць, што яно належыць вам</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Ф&amp;айл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Наладкі</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Дапамога</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Запатрабаваць плацёж (генеруецца QR-код для біткойн URI)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Паказаць спіс адрасоў і метак для дасылання</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Паказаць спіс адрасоў і метак для прымання</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>Опцыі каманднага радка</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Пераіндэксацыя блокаў на дыску...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 таму</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Апошні прыняты блок генераваны %1 таму.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Транзакцыи пасля гэтай не будуць бачныя.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Памылка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Увага</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Інфармацыя</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Сінхранізавана</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Адкрыць кансоль дыягностыкі і адладкі</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;адрасы Адпраўкі</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;адрасы Прымання</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Наганяем...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Дата: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Колькасць: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Тып: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Метка: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Адрас: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Дасланыя транзакцыі</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Прынятыя транзакцыі</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Гаманец &lt;b&gt;зашыфраваны&lt;/b&gt; і зараз &lt;b&gt;разблакаваны&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Гаманец &lt;b&gt;зашыфраваны&lt;/b&gt; і зараз &lt;b&gt;заблакаваны&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтаў:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Камісія:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Пыл:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Пасля камісіі:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(не)выбраць ўсё</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Рэжым дрэва</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Рэжым спіса</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Колькасць</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Прыняць праз метку</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Прыняць праз адрас</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Пацверджанняў</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Пацверджана</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Капіяваць адрас</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Капіяваць пазнаку</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Капіяваць ID транзакцыі</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Замкнуць непатрачанае</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Адамкнуць непатрачанае</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Капіяваць камісію</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Капіяваць з выняткам камісіі</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Капіяваць байты</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Капіяваць пыл</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>так</translation>
    </message>
    <message>
        <source>no</source>
        <translation>не</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Гаманец</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Зашыфраваць Гаманец</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Рэдагаваць Адрас</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Адрас</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Новы адрас для дасылання</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Рэдагаваць адрас прымання</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Рэдагаваць адрас дасылання</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Немагчыма разблакаваць гаманец</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Генерацыя новага ключа няўдалая</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Будзе створаны новы каталог з данымі.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>імя</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Каталог ужо існуе. Дадайце %1 калі вы збіраецеся стварыць тут новы каталог.</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Command-line options</source>
        <translation>Опцыі каманднага радка</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Вітаем</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Біткойн</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Памылка</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Тып</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Адрас</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Уставіць адрас з буферу абмена</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Опцыі</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Гаманец</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Памылка</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Зачыніць</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Type</source>
        <translation>Тып</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Колькасць</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 і %2</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>невядома</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Інфармацыя</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Гаманец: </translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Капіяваць адрас</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Колькасць:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>Метка:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">&amp;Паведамленне:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Капіяваць адрас</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Капіяваць пазнаку</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Немагчыма разблакаваць гаманец</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Адрас:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Метка:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Паведамленне:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Гаманец:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Капіяваць адрас</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Паведамленне</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Даслаць Манеты</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Недастаткова сродкаў</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтаў:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Камісія:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Пасля камісіі:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Выбраць...</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Даслаць адразу некалькім атрымальнікам</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Пыл:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Баланс:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Пацвердзіць дасыланне</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">Даслаць</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Капіяваць камісію</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Капіяваць з выняткам камісіі</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Капіяваць байты</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Капіяваць пыл</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Пацвердзіць дасыланне манет</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Даслаць</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Велічыня плацяжу мае быць больш за 0.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Колькасць:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Заплаціць да:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>Метка:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Уставіць адрас з буферу абмена</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Паведамленне:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Заплаціць да:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Памятка:</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Уставіць адрас з буферу абмена</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>Праверыць паведамленне</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">Праверыць паведамленне</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>Кб/с</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/непацверджана</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 пацверджанняў</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>невядома</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Паведамленне</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Каментар</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Колькасць</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Гэтая панэль паказвае дэтальнае апісанне транзакцыі</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тып</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Пацверджана (%1 пацверджанняў)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Згенеравана, але не прынята</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Прынята з</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Прынята ад</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Даслана да</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Плацёж самому сабе</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Здабыта</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>непазначаны</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Статус транзакцыі. Навядзіце курсар на гэтае поле, каб паказаць колькасць пацверджанняў.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Дата і час, калі транзакцыя была прынята.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Тып транзакцыі</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Колькасць аднятая ці даданая да балансу.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Усё</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сёння</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Гэты тыдзень</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Гэты месяц</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Мінулы месяц</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Гэты год</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Прамежак...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Прынята з</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Даслана да</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Здабыта</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Іншыя</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Мін. колькасць</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Капіяваць адрас</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Капіяваць пазнаку</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Капіяваць ID транзакцыі</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;Рэдагаваць пазнаку</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Коскамі падзелены файл (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Пацверджана</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тып</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрас</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспартаванне няўдалае</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Прамежак:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>да</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Памылка</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Даслаць Манеты</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>Экспарт</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Экспартаваць гэтыя звесткі у файл</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Стварыць копію гаманца</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>Ці жадаеце вы перабудаваць зараз базу звестак блокаў?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Памылка ініцыялізацыі базвы звестак блокаў</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation>Памалка ініцыялізацыі асяроддзя базы звестак гаманца %s!</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Памылка загрузкі базвы звестак блокаў</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>Памылка адчынення базы звестак блокаў</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Памылка</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Імпартаванне...</translation>
    </message>
    <message>
        <source>Not enough file descriptors available.</source>
        <translation>Не хапае файлавых дэскрыптараў.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Праверка блокаў...</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Памылка подпісу транзакцыі</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>Гэта эксперыментальная праграма.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Транзакцыя занадта малая</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Транзакцыя занадта вялікая</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Недастаткова сродкаў</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Загружаем індэкс блокаў...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Загружаем гаманец...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Перасканаванне...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Загрузка выканана</translation>
    </message>
</context>
</TS>